<?php
// set application defaults
$defaults='INCLUDEFOLDER;IMAGEFOLDER;DATAFOLDER;TITLE;';

$inifile='autodirector.ini';
$ini=parse_ini_file($inifile);
foreach ($ini as $key=>$value) {
	define($key, $value);
	$defaults=str_replace($key.';', '', $defaults);
}
unset($ini);

// missing application defaults
if ($defaults!='') {
	print "The following parameters are missing from the $inifile file:\n $defaults";
	exit;
}
unset($defaults);


// ________________________________________________________
// MAIN APPLICATION

// PHP includes
require(INCLUDEFOLDER.'dbhandler.php');
require(INCLUDEFOLDER.'aduser.php');
require(INCLUDEFOLDER.'adsite.php');
require(INCLUDEFOLDER.'adfunctions.php');

// set defaults
define('USERID', readCookie('aduserid'));
define('THISURL', $_SERVER['PHP_SELF']);
define('FULLURL', scriptPath());

// setup database object
$db=new dbObject;

// find out user information
$thisUser=new userObject;
$thisUser->selectDB($db);

// no user ID defined - return to login
if (USERID=='') {
	header('Location: '.FULLURL.'index.php');
	exit();
}
else {
	if (!$thisUser->fetchUser(USERID)) {
		print '<html><head><title>AutoDirector</title></head><body><p>The user account '.USERID.' is not defined, or a database communication error has occurred. Please <a href="index.php">log in again</a> or contact your administrator.</p></body></html>';
		exit();
	}
}

// page header
$pagetitle=' site administration';
require(INCLUDEFOLDER.'adpagehead.php');

// JavaScript includes
print '<script type="text/javascript" src="'.INCLUDEFOLDER.'adscript.js"></script>';
print '<script type="text/javascript" src="'.INCLUDEFOLDER.'adscriptsite.js"></script>';

// JavaScript setup
print "<script type=\"text/javascript\">\n";
print "run+=\"startup();\";\n";
print "function startup() { form=document.autodirector; }\n";
print "</script>\n";

// set page value
$page=postvar('page', '');

// editing
$editrecord=postvar('editrecord', '');

// cancel editing
if ($page=='canceledit') $page='';

// update record
if ($page=='update') {
	fetchSiteForm();
	$operation=$page;
	$page='';
	$result=updateRecord();
}

// delete records
if ($page=='delete') {
	$operation='delete';
	$result=deleteRecords();
	$page='';
}

// show menu
if ($page=='edit') showMenu('siteedit'); else showMenu('sitelist');

// start form
print '<form name="autodirector" action="'.THISURL.'" method="post">';
doHidden('page');

// show site list
showList($page=='');

// show edit page
showEdit($page=='edit');

// end form
print '</form>';


// disconnect from database
$db->dbDisconnect();
unset($db);

// unload variables
unset($thisUser);

// page footer
require(INCLUDEFOLDER.'adpagefoot.php');


// ________________________________________________________
// shows all available sites (depends on user permission)
function showList($show=true) {

	global $db, $thisUser, $operation, $result;

	// available page sizes
	$pagesizelist=Array(10, 20, 30, 50, 100);

	$pagesize=intval(postvar('pagesize', $pagesizelist[0]));
	$pagenum=intval(postvar('pagenum', 1));
	$sortby=postvar('sortby', 'siteid');
	$sorttype=postvar('sorttype', 'ASC');
	$allSites='';

	doHidden('pagenum', $pagenum);
	doHidden('sortby', $sortby);
	doHidden('sorttype', $sorttype);

	if ($show) {

		doHidden('editrecord');
		doHidden('delrecords');

		// find list of valid sites for this user (supervisors are exempt)
		if (!$thisUser->supervisor) {
			$validSites=$thisUser->adminsites.$thisUser->usersites;
			$validSites=str_replace('][', '],[', $validSites);
			$validSites=str_replace('[', "'", $validSites);
			$validSites=str_replace(']', "'", $validSites);
			if ($validSites=='') $validSites="'#NO SITES#'";
			$validSites="WHERE siteid IN ($validSites)";
		}
		else $validSites='';

		// show list of sites
		$db->pagesize=$pagesize;
		if ($db->fetch("SELECT siteid FROM sites $validSites ORDER BY $sortby $sorttype;")) {

			if ($db->rowcount==0) {
				print '<p class="error">You do not have access to any sites.</p>';
			}
			else {

				if ($pagenum>$db->pagecount) { $pagenum=$db->pagecount; }
				$db->pagejump($pagenum);

				// site object
				$site=new siteObject;
				$site->selectDB($db);

				// retrieve information for all available sites
				for ($i=$db->rowfrom; $i<=$db->rowto; $i++) {
					$row=$db->row();
					$sitelist[] = $row[0];
				}

				for ($i=0; $i<count($sitelist); $i++) {
					if ($site->fetchSite($sitelist[$i])) {
						$allSites.='<tr>';

						// edit site settings (super or admin-not blocked)
						if ($thisUser->permissionLevel($site->siteid)==3 || ($thisUser->permissionLevel($site->siteid)==2 && !$site->blocksiteadmin)) $allSites.="<td class=\"sortby\"><a href=\"javascript:edititem('$site->siteid')\" title=\"edit this site's settings\" onmouseover=\"rowColour('$site->siteid','rowover')\" onmouseout=\"rowColour('$site->siteid','rowout')\" class=\"edit\">edit&nbsp;<img src=\"".IMAGEFOLDER."arrowrt.gif\" border=\"0\" align=\"absmiddle\" /></a></td>";
						else $allSites.='<td class="sortby">&nbsp;</td>';

						// delete box (super)
						if ($thisUser->supervisor) $allSites.="<td class=\"sortby\"><input type=\"checkbox\" name=\"$site->siteid\" /></td>";

						$allSites.="<td id=\"{$site->siteid}_1\"><b>$site->siteid</b></td>";
						$allSites.="<td id=\"{$site->siteid}_2\">";
						if ($site->emailsales!='') $allSites.="<a href=\"mailto:{$site->emailsales}?subject=Showroom:%20{$site->siteid}\">".truncEmail($site->emailsales).'</a>';
						else  $allSites.='&nbsp;';
						$allSites.='</td>';
						$allSites.="<td id=\"{$site->siteid}_3\">$site->currency</td>";
						$allSites.="<td id=\"{$site->siteid}_4\" align=\"right\">$site->maxusers</td>";
						$allSites.="<td id=\"{$site->siteid}_5\" align=\"right\">".number_format($site->maxentries).'</td>';
						$allSites.="<td id=\"{$site->siteid}_6\" align=\"right\">$site->maxpics</td>";
						$allSites.="<td id=\"{$site->siteid}_7\">".date("d-m-y H:i", timeconv($site->lastupdate)).'</td>';
						$allSites.="<td id=\"{$site->siteid}_8\">";
						if ($site->userupdate!='') $allSites.="<a href=\"mailto:{$site->userupdate}?subject=Showroom:%20{$site->siteid}\">".truncEmail($site->userupdate).'</a>';
						else $allSites.='&nbsp;';
						$allSites.='</td>';
						$allSites.="<td id=\"{$site->siteid}_9\">";
						if ($site->blocksiteadmin) $allSites.="<a href=\"javascript:showBlock('{$site->siteid}','site');\" onmouseover=\"rowColour('$site->siteid','rowover')\" onmouseout=\"rowColour('$site->siteid','rowout')\"><img src=\"".IMAGEFOLDER."iconblocksite.gif\" width=\"16\" height=\"16\" border=\"0\" hspace=\"3\" alt=\"site\" title=\"site administration is blocked\" /></a>";
						else $allSites.='<img src="'.IMAGEFOLDER.'spacer.gif" width="16" height="16" hspace="3" />';

						if ($site->blockuseradmin) $allSites.="<a href=\"javascript:showBlock('{$site->siteid}','user');\" onmouseover=\"rowColour('$site->siteid','rowover')\" onmouseout=\"rowColour('$site->siteid','rowout')\"><img src=\"".IMAGEFOLDER."iconblockuser.gif\" width=\"16\" height=\"16\" border=\"0\" hspace=\"3\" alt=\"users\" title=\"user administration is blocked\" /></a>";
						else $allSites.='<img src="'.IMAGEFOLDER.'spacer.gif" width="16" height="16" hspace="3" />';

						if ($site->blockvehicleadmin) $allSites.="<a href=\"javascript:showBlock('{$site->siteid}','vehicle');\" onmouseover=\"rowColour('$site->siteid','rowover')\" onmouseout=\"rowColour('$site->siteid','rowout')\"><img src=\"".IMAGEFOLDER."iconblockvehicle.gif\" width=\"16\" height=\"16\" border=\"0\" hspace=\"3\" alt=\"vehicles\" title=\"vehicle administration is blocked\" /></a>";
						else $allSites.='<img src="'.IMAGEFOLDER.'spacer.gif" width="16" height="16" hspace="3" />';

						if ($site->blockgenerate) $allSites.="<a href=\"javascript:showBlock('{$site->siteid}','generate');\" onmouseover=\"rowColour('$site->siteid','rowover')\" onmouseout=\"rowColour('$site->siteid','rowout')\"><img src=\"".IMAGEFOLDER."iconblocklist.gif\" width=\"16\" height=\"16\" border=\"0\" hspace=\"3\" alt=\"site list\" title=\"site list generation is blocked\" /></a>";
						$allSites.='</td>';

						$allSites.="<td id=\"{$site->siteid}_10\">";

						// administer users (super or admin not blocked)
						if ($thisUser->permissionLevel($site->siteid)==3 || ($thisUser->permissionLevel($site->siteid)==2 && !$site->blockuseradmin)) $allSites.="<a href=\"useradmin.php?siteid={$site->siteid}\" onmouseover=\"rowColour('$site->siteid','rowover')\" onmouseout=\"rowColour('$site->siteid','rowout')\"><img src=\"".IMAGEFOLDER."iconusers.gif\" width=\"16\" height=\"16\" border=\"0\" hspace=\"3\" alt=\"users\" title=\"user administration\" /></a>";
						else $allSites.='<img src="'.IMAGEFOLDER.'spacer.gif" width="16" height="16" hspace="3" />';

						// administer/import vehicles (super or admin/user not blocked)
						if ($thisUser->permissionLevel($site->siteid)==3 || !$site->blockvehicleadmin) {
						
							$allSites.="<a href=\"vehicleadmin.php?siteid={$site->siteid}\" onmouseover=\"rowColour('$site->siteid','rowover')\" onmouseout=\"rowColour('$site->siteid','rowout')\"><img src=\"".IMAGEFOLDER."iconcar.gif\" width=\"16\" height=\"16\" border=\"0\" hspace=\"3\" alt=\"vehicles\" title=\"vehicle administration\" /></a>";
							
							$allSites.="<a href=\"importadmin.php?siteid={$site->siteid}\" onmouseover=\"rowColour('$site->siteid','rowover')\" onmouseout=\"rowColour('$site->siteid','rowout')\"><img src=\"".IMAGEFOLDER."iconimport.gif\" width=\"16\" height=\"16\" border=\"0\" hspace=\"3\" alt=\"vehicles\" title=\"vehicle import wizard\" /></a>";
						
						}
						else $allSites.='<img src="'.IMAGEFOLDER.'spacer.gif" width="35" height="16" hspace="3" />';

						// administer site generation (not blocked)
						if ($thisUser->permissionLevel($site->siteid)==3 || !$site->blockgenerate) $allSites.="<a href=\"listadmin.php?siteid={$site->siteid}\" onmouseover=\"rowColour('$site->siteid','rowover')\" onmouseout=\"rowColour('$site->siteid','rowout')\"><img src=\"".IMAGEFOLDER."iconlist.gif\" width=\"16\" height=\"16\" border=\"0\" hspace=\"3\" alt=\"integration\" title=\"integration options\" /></a>";

						$allSites.='</td></tr>';
					}

				}

				if ($allSites=='') {
					print '<p class="error">No sites can be displayed. Your rights may have been revoked.</b></p>';
				}
				else {

					// table header
					if ($thisUser->supervisor) $cols=12; else $cols=11;
					print '<table align="center" border="0" cellpadding="2" cellspacing="1" bgcolor="#000000">';
					print "<tr><td colspan=\"$cols\" class=\"heading\">Your site list</td></tr>";
					print '<tr><th class="sortby">&nbsp;</th>';
					if ($thisUser->supervisor) print '<th class="sortby">&nbsp;</th>';
					print '<th class="sortby'.($sortby=='siteid').'">site&nbsp;<a href="javascript:tablesort(\'siteid\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'siteid\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
					print '<th class="sortby'.($sortby=='emailsales').'">sales&nbsp;<a href="javascript:tablesort(\'emailsales\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'emailsales\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
					print '<th class="sortby'.($sortby=='currency').'">cur&nbsp;<a href="javascript:tablesort(\'currency\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'currency\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
					print '<th class="sortby'.($sortby=='maxusers').'">usrs&nbsp;<a href="javascript:tablesort(\'maxusers\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'maxusers\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
					print '<th class="sortby'.($sortby=='maxentries').'">ents&nbsp;<a href="javascript:tablesort(\'maxentries\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'maxentries\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
					print '<th class="sortby'.($sortby=='maxpics').'">pics&nbsp;<a href="javascript:tablesort(\'maxpics\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'maxpics\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
					print '<th class="sortby'.($sortby=='lastupdate').'">modified&nbsp;<a href="javascript:tablesort(\'lastupdate\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'lastupdate\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
					print '<th class="sortby'.($sortby=='userupdate').'">by&nbsp;<a href="javascript:tablesort(\'userupdate\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'userupdate\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
					print '<th class="sortby">alerts</th><th class="sortby">admin</th></tr>';
					print $allSites;
					print "<th colspan=\"$cols\" class=\"sortby\"><table width=\"100%\" border=\"0\" cellpadding=\"0\" cellspacing=\"1\"><tr>";
					if ($thisUser->supervisor) print '<td class="sortby"><input type="button" value="delete selected" onclick="deleteselected()" class="button" /></td>';
					print "<td align=\"center\" class=\"sortby\"><b>Viewing sites $db->rowfrom to $db->rowto of $db->rowcount</b></td>";
					print '<td align="right" class="sortby">Show <select name="pagesize" onchange="if (loaded) { form.pagenum.value=1;this.form.submit(); }">';
					for ($i=0; $i<sizeof($pagesizelist); $i++) {
						print "<option value=\"$pagesizelist[$i]\"";
						if ($pagesize==$pagesizelist[$i]) { print " selected"; }
						print ">$pagesizelist[$i]</option>";
					}
					print '</select> per page</td><td align="right" class="sortby">&nbsp;';

					// back button
					if ($pagenum>1) { print '<a href="javascript:jumppage('.($pagenum-1).')"><img src="'.IMAGEFOLDER.'arrowlt.gif" border="0" alt="previous page" /></a>&nbsp;'; }

					// page drop down
					if ($db->pagecount>1) {
						print '<select name="gopage" onchange="jumppage(this.options[this.selectedIndex].value)">';
						for ($i=1; $i<=$db->pagecount; $i++) {
							print '<option ';
							if ($i==$pagenum) { print 'value="0" style="color:#666666;" selected>'; } else { print "value=\"$i\">"; }
							print "page $i</option>";
						}
						print '</select>';
					}

					// next button
					if ($pagenum<$db->pagecount) { print '&nbsp;<a href="javascript:jumppage('.($pagenum+1).')"><img src="'.IMAGEFOLDER.'arrowrt.gif" border="0" alt="next page" /></a>'; }
					print '</td></tr></table></th></table><br clear="all" />';

				}

			}

			// add a new site
			if ($thisUser->supervisor) {
				print '<div align="center"><input type="button" value="create a new site" onclick="edititem(\'\')" class="button" /></div><br clear="all" /><br />';
			}

		}
		else {
			print '<p align="center" class="error">The database is not available. Please contact your administrator.</p>';
		}

		// operations
		if ($operation!='') { print "<p align=\"center\" class=\"error\">$result</p>"; }

		// show table key
		if ($allSites!='') print '<p><table border="0" cellpadding="2" cellspacing="0"><tr><td colspan="2"><b class="error">Key:</b></td></tr><tr><td><b>sales</b></td><td>email used for vehicle enquiries</td></tr><tr><td><b>cur</b></td><td>currency used</td></tr><tr><td><b>usrs</b></td><td>permitted number of users who can update a site</td></tr><tr><td><b>ents</b></td><td>maximum number of vehicle entries</td></tr><tr><td><b>pics</b></td><td>maximum number pictures per vehicle</td></tr><tr><td><b>alerts</b></td><td>click or hover over an icon for more information</td></tr><tr><td><b>admin</b></td><td>click an icon to access a feature</td></tr></table></p>';

	}
	else {
		// list not shown
		doHidden('pagesize', $pagesize);
	}

}


// ________________________________________________________
// shows site edit screen
function showEdit($show=false) {

	global $db, $thisUser, $editrecord, $operation, $result;
	global $siteid, $emailsales, $currency, $maxusers, $maxentries, $maxpics, $picdimension, $forcedimension, $thumbdimx, $thumbdimy, $searchon, $orderbyon, $adverton, $blockgenerate, $blockvehicleadmin, $blockuseradmin, $blocksiteadmin;

	// does user have access to site add/edit
	if ($show) {
		if ($editrecord!='') {
			if ($thisUser->permissionLevel($editrecord)<2) {
				print "<p class=\"error\">You do not have permission to edit the site '$editrecord'.</p>";
				$show=false;
			}
		}
		else {
			if (!$thisUser->supervisor) {
				print "<p class=\"error\">You do not have permission to add new sites.</p>";
				$show=false;
			}
		}
	}

	// show add/edit panel
	if ($show) {

		doHidden('editrecord', $editrecord);
		$curtypes=array('GBP'=>'&pound; pound', 'EURO'=>'&euro; euro', 'USD'=>'$ dollar');

		// no current operation
		if ($operation=='') {

			if ($editrecord=='') {

				// set site defaults
				$siteid='';
				$emailsales='';
				$currency='GBP';
				$maxusers=1;
				$maxentries=10;
				$maxpics=1;
				$picdimension=600;
				$forcedimension=false;
				$thumbdimx=80;
				$thumbdimy=60;
				$searchon=false;
				$orderbyon=true;
				$adverton=true;
				$blockgenerate=false;
				$blockvehicleadmin=false;
				$blockuseradmin=false;
				$blocksiteadmin=false;

			}
			else {

				// fetch site
				$site=new siteObject;
				$site->selectDB($db);
				if ($site->fetchSite($editrecord)) {
					$siteid=$site->siteid;
					$emailsales=$site->emailsales;
					$currency=$site->currency;
					$maxusers=$site->maxusers;
					$maxentries=$site->maxentries;
					$maxpics=$site->maxpics;
					$picdimension=$site->picdimension;
					$forcedimension=$site->forcedimension;
					$thumbdimx=$site->thumbdimx;
					$thumbdimy=$site->thumbdimy;
					$searchon=$site->searchon;
					$orderbyon=$site->orderbyon;
					$adverton=$site->adverton;
					$blockgenerate=$site->blockgenerate;
					$blockvehicleadmin=$site->blockvehicleadmin;
					$blockuseradmin=$site->blockuseradmin;
					$blocksiteadmin=$site->blocksiteadmin;
				}
				else print '<p class="error">WARNING: site data could not be retrieved. Please cancel and try again.</p>';
			}
		}

		// show error message
		if ($result!='') print "<p class=\"error\">$result</p>";

		// show edit form
		print '<table align="center" border="0" cellpadding="0" cellspacing="1">';

		print '<tr><td valign="top"><table border="0" cellpadding="0" cellspacing="1">';
		print '<tr><td class="question"><b>unique site id</b></td></tr><tr><td class="field">';
		if ($editrecord=='') print '<input type="text" name="siteid" value="" size="22" maxlength="20" onchange="this.value=String(this.value).toLowerCase()"/>';
		else {
			print $siteid;
			doHidden('siteid', $siteid);
		}
		print '</td></tr><tr><td class="question"><br /><b>sales email address</b></td></tr><tr><td class="field"><input type="text" name="emailsales" value="'.$emailsales.'" size="30" maxlength="100" /></td></tr><tr><td class="question"><br /><b>site currency</b></td></tr><tr><td class="field"><select name="currency">';
		foreach ($curtypes as $ccode => $cval) {
			print "<option value=\"$ccode\"";
			if ($currency==$ccode) { print " selected"; }
			print ">$cval</option>";
		}
		print '</select></td></tr>';
		print '</table></td><td valign="top">';

		// supervisor only options: maxusers, maxvehicles, maxpics
		if ($thisUser->supervisor) {
			print '<table align="right" border="0" cellpadding="0" cellspacing="1">';
			print '<tr><td class="question"><b>maximum site users</b></td></tr><tr><td class="field"><input type="text" name="maxusers" value="'.$maxusers.'" size="6" maxlength="3" onchange="this.value=format_integer(this.value);" style="text-align:right;" /></td></tr>';
			print '<tr><td class="question"><br /><b>maximum vehicles</b></td></tr><tr><td class="field"><input type="text" name="maxentries" value="'.$maxentries.'" size="6" maxlength="5" onchange="this.value=format_integer(this.value);" style="text-align:right;" /></td></tr>';
			print '<tr><td class="question"><br /><b>maximum&nbsp;pictures&nbsp;per&nbsp;vehicle</b></td></tr><tr><td class="field"><input type="text" name="maxpics" value="'.$maxpics.'" size="6" maxlength="3" onchange="this.value=format_integer(this.value);" style="text-align:right;" /></td></tr>';
			print '</table>';
		}
		else {
			print "&nbsp;";
			doHidden('maxusers', $maxusers);
			doHidden('maxentries', $maxentries);
			doHidden('maxpics', $maxpics);
		}

		print '</td></tr>';

		print '<tr><td colspan="2" class="line">&nbsp;</td></tr>';

		print '<tr><td class="question"><b>resized picture dimension</b></td><td class="question"><input type="checkbox" name="forcedimension"';
		if ($forcedimension) print " checked";
		print ' />&nbsp;<a href="javascript:toggleCheckbox(\'forcedimension\')" class="field"><b>enforce this dimension</b></a></td></tr>';
		print '<tr><td class="field"><input type="text" name="picdimension" value="'.$picdimension.'" size="6" maxlength="5" onchange="this.value=format_integer(this.value);" style="text-align:right;" />&nbsp;pixels&sup2;</td><td valign="top" class="field"><i>(reject pictures of less width and height)</i></td></tr>';

		print '<tr><td class="question"><br /><b>thumbnail width</b></td><td class="question"><br /><b>thumbnail height</b></td></tr>';
		print '<tr><td class="field"><input type="text" name="thumbdimx" value="'.$thumbdimx.'" size="6" maxlength="3" onchange="this.value=format_integer(this.value);" style="text-align:right;" />&nbsp;pixels</td><td class="field"><input type="text" name="thumbdimy" value="'.$thumbdimy.'" size="6" maxlength="3" onchange="this.value=format_integer(this.value);" style="text-align:right;" />&nbsp;pixels</td></tr>';

		print '<tr><td colspan="2" class="line">&nbsp;</td></tr>';

		print '<tr><td valign="top" class="question"><b>options:</b><br /><table border="0" cellpadding="0" cellspacing="1">';
		print '<tr><td class="question"><input type="checkbox" name="orderbyon"';
		if ($orderbyon) print " checked";
		print ' />&nbsp;<a href="javascript:toggleCheckbox(\'orderbyon\')" class="field">display ordering options</a></td></tr>';
		print '<tr><td class="question"><input type="checkbox" name="searchon"';
		if ($searchon) print " checked";
		print ' />&nbsp;<a href="javascript:toggleCheckbox(\'searchon\')" class="field">display search box</a></td></tr>';
		print '<tr><td class="question"><input type="checkbox" name="adverton"';
		if ($adverton) print " checked";
		print ' />&nbsp;<a href="javascript:toggleCheckbox(\'adverton\')" class="field">display advert on list</a></td></tr>';

		print '</table></td><td valign="top" class="question">';

		if ($thisUser->supervisor) {
			print '<b>alerts:</b><br /><table border="0" cellpadding="0" cellspacing="1">';
			print '<tr><td class="question"><input type="checkbox" name="blocksiteadmin"';
			if ($blocksiteadmin) print " checked";
			print ' />&nbsp;<a href="javascript:toggleCheckbox(\'blocksiteadmin\')" class="field">block site administration</a></td></tr>';
			print '<tr><td class="question"><input type="checkbox" name="blockuseradmin"';
			if ($blockuseradmin) print " checked";
			print ' />&nbsp;<a href="javascript:toggleCheckbox(\'blockuseradmin\')" class="field">block user administration</a></td></tr>';
			print '<tr><td class="question"><input type="checkbox" name="blockvehicleadmin"';
			if ($blockvehicleadmin) print " checked";
			print ' />&nbsp;<a href="javascript:toggleCheckbox(\'blockvehicleadmin\')" class="field">block vehicle administration</a></td></tr>';
			print '<tr><td class="question"><input type="checkbox" name="blockgenerate"';
			if ($blockgenerate) print " checked";
			print ' />&nbsp;<a href="javascript:toggleCheckbox(\'blockgenerate\')" class="field">block site generation</a></td></tr>';
			print '</table>';
		}
		else {
			print "&nbsp;";
			doHidden('blocksiteadmin', $blocksiteadmin);
			doHidden('blockuseradmin', $blockuseradmin);
			doHidden('blockvehicleadmin', $blockvehicleadmin);
			doHidden('blockgenerate', $blockgenerate);
		}

		print '</td></tr>';

		print '<tr><td colspan="2" class="line">&nbsp;</td></tr>';
		print '</table><br clear="all" />';

		print '<div align="center"><input type="button" value="save site" onclick="checkSite()" class="button" />&nbsp;<input type="button" value="cancel" onclick="cancelUpdate()" class="button" /></div>';

	}

}


// ________________________________________________________
// update or insert a record
function updateRecord() {

	global $db, $thisUser;
	global $editrecord, $page;
	global $siteid, $emailsales, $currency, $maxusers, $maxentries, $maxpics, $picdimension, $forcedimension, $thumbdimx, $thumbdimy, $searchon, $orderbyon, $adverton, $blockgenerate, $blockvehicleadmin, $blockuseradmin, $blocksiteadmin;

	$ret='';
	$thisSite=new siteObject;
	$thisSite->selectDB($db);

	// create a new site
	if ($editrecord=='') {
		if ($thisUser->supervisor) {
			if ($siteid=='sites' || $siteid=='users' || $thisSite->fetchSite($siteid)) {
				$ret="The site ID '$siteid' is already in use. Please try a different name.";
				$page="edit";
			}
			else {
				// create the new site
				if ($thisSite->createSite($siteid)) $editrecord=$siteid;
				else {
					$ret="The site '$siteid' could not be created. Please try a different name or contact your administrator.";
					$page="edit";
				}
			}
		}
		else $ret='You do not have permission to add new sites.';
	}


	// update record
	if ($editrecord!='') {
		$siteid=$editrecord;

		// fetch existing site
		if ($thisSite->fetchSite($siteid)) {

			// get user permission
			$plevel=$thisUser->permissionLevel($siteid);

			// super user updates
			if ($plevel==3) {
				$thisSite->maxusers=$maxusers;
				$thisSite->maxentries=$maxentries;
				$thisSite->maxpics=$maxpics;
				$thisSite->blockgenerate=$blockgenerate;
				$thisSite->blockvehicleadmin=$blockvehicleadmin;
				$thisSite->blockuseradmin=$blockuseradmin;
				$thisSite->blocksiteadmin=$blocksiteadmin;
			}

			// admin level updates
			if ($plevel>=2) {
				$thisSite->emailsales=$emailsales;
				$thisSite->currency=$currency;
				$thisSite->picdimension=$picdimension;
				$thisSite->forcedimension=$forcedimension;
				$thisSite->thumbdimx=$thumbdimx;
				$thisSite->thumbdimy=$thumbdimy;
				$thisSite->searchon=$searchon;
				$thisSite->orderbyon=$orderbyon;
				$thisSite->adverton=$adverton;

				if ($thisSite->updateSite($thisUser->email)) {
					$ret.=" Site '$siteid' has been updated.<br />";
					$ret.=generateFiles($thisSite, FULLURL, DATAFOLDER);
				}
				else $ret="A database error occurred when updating site '$siteid'. Please contact your administrator.";
			}
			else $ret="You do not have permission to edit the site '$siteid'.";

		}
		else $ret="The site '$siteid' could not be retreived from the database. Please contact your administrator.";

	}

	return $ret;
}

// ________________________________________________________
// delete selected records
function deleteRecords() {

	global $db, $thisUser;
	$ret='';

	if ($thisUser->supervisor) {

		$sites=explode(',', postvar('delrecords'));

		$thisSite=new siteObject;
		$thisSite->selectDB($db);

		foreach ($sites as $site) {
			if ($thisSite->fetchSite($site)) $ret.=$thisSite->deleteSite($thisUser->email);
			else $ret.="Site '$site' could not be deleted owing to a database communication error. Please contact your administrator.";
		}

	}
	else $ret.="You do not have permission to delete sites.";

	return $ret;
}


// ________________________________________________________
// fetch site form
function fetchSiteForm() {

	global $siteid, $emailsales, $currency, $maxusers, $maxentries, $maxpics, $picdimension, $forcedimension, $thumbdimx, $thumbdimy, $searchon, $orderbyon, $adverton, $blockgenerate, $blockvehicleadmin, $blockuseradmin, $blocksiteadmin;

	$siteid=postvar('siteid');
	$emailsales=trim(postvar('emailsales'));
	$currency=postvar('currency');
	$maxusers=numericvar('maxusers', 1, 50);
	$maxentries=numericvar('maxentries', 1, 10000);
	$maxpics=numericvar('maxpics', 1, 10);
	$picdimension=numericvar('picdimension', 200, 800);
	$forcedimension=boolvar('forcedimension');
	$thumbdimx=numericvar('thumbdimx', 40, 200);
	$thumbdimy=numericvar('thumbdimy', 40, 200);
	$searchon=boolvar('searchon');
	$orderbyon=boolvar('orderbyon');
	$adverton=boolvar('adverton');
	$blockgenerate=boolvar('blockgenerate');
	$blockvehicleadmin=boolvar('blockvehicleadmin');
	$blockuseradmin=boolvar('blockuseradmin');
	$blocksiteadmin=boolvar('blocksiteadmin');
}


// ________________________________________________________
// fetch a numeric value and ensure it is in range
function numericvar($field='nofield', $min=1, $max=5) {
	$ret=postvar($field);
	$ret=preg_replace('/\D/', '', $ret);
	if (is_numeric($ret)) $ret=intval($ret); else $ret=$min;
	if ($ret>$max) $ret=$max;
	return $ret;
}

// ________________________________________________________
// fetch a boolean value
function boolvar($field='nofield') {
	$val=strtolower(trim(postvar($field)));
	if ($val=='on' || $val=='true') $ret=true; else $ret=false;
	return $ret;
}
?>